calculate.GSEA(tab, phenotype, gsList, nsim = 1000, verbose = FALSE, alwaysUseRandomPerm = FALSE)selectGeneSets functionnsim is greater
than the total number of unique permutations possible with the
phenotype vector The function also normalizes the GSEA statistic and calculates the
corresponding q-values for each gene set as described in Tian
et al. (2005) The function's output can be used for further analysis
in other functions such as rankPathways.NGSk or
getPathwayStatistics.NGSk.