calculate.NTk, calculate.NEk, calculate.NGSk, or
calculate.GSEA)
rankPathways.NGSk(res.NGSk, G, gsList, methodName = "NGSk", npath = 25)calculate.NGSk,
calculate.NTk, calculate.NEk, or
calculate.GSEAselectGeneSets functionres.NGSkG, gene set
category, pathway title, set size, res.NGSk's statistics,
the corresponding q-values, and the numerical ranks for the top gene sets.
res.NGSk and
summarizes the top gene sets in a tabular format similar to Table 2 in
Tian et al. (2005)